@@ -126,6 +126,7 @@ class Phase:
         self.apc = None
         self.vol = None
         self.concentration = None
+        self.dumpfile = False
         self.prepare_lattice()
 
         #other properties
@@ -194,16 +195,22 @@ class Phase:
         Calculates the lattic, lattice constant, number of atoms per unit cell
         and concentration of the input system.
         """
-        l, alat, apc, conc = pl.prepare_lattice(self.calc)
+        l, alat, apc, conc, dumpfile = pl.prepare_lattice(self.calc)
         self.l = l
         self.alat = alat
         self.apc = apc
         self.concentration = conc
+        self.dumpfile = dumpfile
         self.logger.info("Lattice: %s with a=%f"%(self.l, self.alat))
         self.logger.info("%d atoms in the unit cell"%self.apc)
         self.logger.info("concentration:")
         self.logger.info(self.concentration)
-
+        if self.l == "file":
+            if self.dumpfile:
+                self.logger.info("Input structure is read in from a LAMMPS dump file")
+            else:
+                self.logger.info("Input structure is read in from a LAMMPS data file")
+                
     def dump_current_snapshot(self, lmp, filename):
         """
         """
@@ -721,8 +728,6 @@ class Phase:
             lmp.command("undump           d1")
 
         #switch potential
-        lmp = ph.set_potential(lmp, self.calc)
-
         lmp.command("run               %d"%self.calc.n_equilibration_steps)
 
         #check melting or freezing
@@ -732,6 +737,8 @@ class Phase:
         else:
             self.check_if_solidfied(lmp, "traj.temp.dat")
 
+        lmp = ph.set_potential(lmp, self.calc)
+
         #reverse scaling
         lmp.command("variable         flambda equal ramp(${li},${lf})")
         lmp.command("variable         blambda equal ramp(${lf},${li})")
